@@ -1,6 +1,7 @@
 import contextlib
 import decimal
 import functools
+import itertools
 import json
 import operator
 import pathlib
@@ -47,6 +48,17 @@ def format_version_validator(instance, attribute, value):
         )
 
 
+def parse_units(unit_string):
+    if unit_string is not None:
+        unit_string = unit_string.replace('%', ' percent ')
+        # TODO: this is terrible T1179
+        unit_string = unit_string.replace('nominal', '')
+        unit_string = unit_string.replace('Power', '')
+        unit_string = unit_string.replace('cos()', '')
+
+    return epyqlib.utils.units.registry.parse_units(unit_string)
+
+
 @attr.s
 class Definition:
     base_path = attr.ib()
@@ -180,11 +192,7 @@ class Signal:
         return self.set(value=value)
 
     def units(self):
-        unit = self.signal.unit
-        if unit is not None:
-            unit = unit.replace('%', ' percent ')
-
-        return epyqlib.utils.units.registry.parse_units(unit)
+        return parse_units(self.signal.unit)
 
     def cyclic_send(self, period):
         self.device.cyclic_send_signal(self, period=period)
@@ -359,11 +367,7 @@ class Nv:
         return value * self.units()
 
     def units(self):
-        unit = self.nv.unit
-        if unit is not None:
-            unit = unit.replace('%', ' percent ')
-
-        return epyqlib.utils.units.registry.parse_units(unit)
+        return parse_units(unit_string=self.nv.unit)
 
 
     @twisted.internet.defer.inlineCallbacks
@@ -891,11 +895,7 @@ class SunSpecNv:
         return value * self.units()
 
     def units(self):
-        unit = self.nv.point_type.units
-        if unit is not None:
-            unit = unit.replace('%', ' percent ')
-
-        return epyqlib.utils.units.registry.parse_units(unit)
+        return parse_units(unit_string=self.nv.point_type.units)
 
 
 @attr.s
@@ -935,23 +935,39 @@ class SunSpecDevice:
     parameter_from_uuid = nv_from_uuid
 
     def map_uuids(self):
-        def get_uuid(point):
-            comment, uuid = epyqlib.canneo.strip_uuid_from_comment(
-                point.point_type.notes,
-            )
+        def get_uuid(block, point):
+            comment = point.point_type.notes
 
-            return uuid
+            for index in itertools.count():
+                comment, uuid = epyqlib.canneo.strip_uuid_from_comment(
+                    comment,
+                )
+
+                if uuid is None:
+                    return uuid
+
+                if block.type == 'fixed':
+                    return uuid
+
+                if block.type == 'repeating' and index == block.index - 1:
+                    return uuid
+
+        points = [
+            [model, block, point]
+            for model in self.device.device.models_list
+            for block in model.blocks
+            for point in [*block.points_list, *block.points_sf.values()]
+            if point.point_type.notes is not None
+        ]
 
         self.uuid_to_point = {
-            get_uuid(point): point
-            for model in self.device.device.models_list
-            for point in model.points_list
+            get_uuid(block=block, point=point): point
+            for model, block, point in points
         }
 
         self.uuid_to_model = {
-            get_uuid(point): model
-            for model in self.device.device.models_list
-            for point in model.points_list
+            get_uuid(block=block, point=point): model
+            for model, block, point in points
         }
 
     async def get_access_level(self):
